@@ -7,12 +7,13 @@ from pyRMSD.matrixHandler import MatrixHandler as pyRMSD_MatrixHandler
 
 class LoaderMatrixCalculator(object):
     
-    CALCULATION_METHOD = "load"
+    CALCULATION_METHOD = "matrix::load"
     
     def __init__(self, params):
         pass
     
-    def calculate(self, data_handler, matrix_params):
+    @classmethod
+    def calculate(cls, data_handler, matrix_params):
         """
         :param matrix_params: The parameters to build the matrix. In this base case the only
         option is "load".
@@ -39,4 +40,4 @@ class LoaderMatrixCalculator(object):
         :return: A CondensedMatrix.
         """
         
-        return pyRMSD_MatrixHandler.load_matrix(self.matrix_parameters["parameters"]["path"])
+        return pyRMSD_MatrixHandler.load_matrix(matrix_params["path"])
